# Asteroid
Asteroid is a modern, multi-paradigm programming language supporting first-class patterns.  More details can
be found at the website [asteroid-lang.org](https://asteroid-lang.org).
Documentation on Asteroid can be found at
[asteroid-lang.readthedocs.io](https://asteroid-lang.readthedocs.io).
